Generic joint plot function
joint_plot_sc.RdDispatches to a joint hexbin plot of library size vs feature counts. See
joint_plot_sc.CellQc and
joint_plot_sc.data.table for the available methods.

joint_plot_sc.RdDispatches to a joint hexbin plot of library size vs feature counts. See
joint_plot_sc.CellQc and
joint_plot_sc.data.table for the available methods.