Dot plot of marker gene expression across groups
dot_plot_sc.RdDot plot of marker gene expression across groups
Arguments
- object
A single cell class.
- features
Character vector. Gene IDs to plot.
- grouping_variable
String. Obs column to group by.
- feature_labels
Optional named character vector mapping gene ids to display labels (default: NULL).
- feature_grouping
Optional named character vector mapping gene ids to grouping labels, e.g. cell type labels. If feature_labels is provided, the character vectors should contain the mapping of feature display labels to their respecitve groups (e.g. c(CD3E = "T cell", CD8A = "T cell", MS4A1 = "B cell", ...). (default: NULL).
- scale_exp
Boolean. Whether to min-max scale mean expression per gene.
- modality
String. One of
c("rna", "adt").- cluster_groups
Boolean. Use hierarchical clustering on the grouping variable to re-order the group labels based on expression similarity.
- palette
String. Continuous palette for the scaled expression. One of
c("sequential", "spectral", "viridis", "diverging"), seebx_colors().
Value
A ggplot object.